use strict;
use warnings;

use AWS::CLIWrapper;

if (@ARGV < 1) {
    print "Usage: load-balancer.pl [instance id]\n";
    exit 1;
}

my @instance_ids = @ARGV;

my $aws = AWS::CLIWrapper->new(
    region => 'ap-northeast-1'
);

$aws->elb('register-instances-with-load-balancer', {
    'load-balancer-name' => $ENV{AWS_ELB_NAME},
    'instances'          => [@instance_ids],
});

# リトライ回数
my $retry = 3;

for my $i (1..$retry) {
    my $states = $aws->elb(
        'describe-instance-health', {
        'load-balancer-name' => $ENV{AWS_ELB_NAME},
    });

    my $out_service = 0;
    for my $instance (@{ $states->{InstanceStates} }) {
        printf("%s ... %s\n",
            $instance->{InstanceId},
            $instance->{State},
        );

        if ($instance->{InstanceId} ne 'InService') {
            $out_service++
        }
    }

    last if $out_service == 0;

    if ($i == $retry) {
        warn "Failure!";
        exit 1;
    }

    sleep 10;
}
